@@ -126,7 +126,12 @@ void dump_config(struct runctl *runp, struct query *querylist)
 
     indent_level = 0;
 
-    fputs("from Tkinter import TRUE, FALSE\n\n", stdout);
+    /*
+     * These had better match the values fetchmailconf is expecting!
+     * (We don't want to import them from Tkinter because the user
+     * might not have it installed.)
+     */
+    fputs("TRUE=1; FALSE=0\n\n", stdout);
 
     /*
      * We need this in order to know whether `interface' and `monitor'
@@ -247,7 +252,7 @@ void dump_config(struct runctl *runp, struct query *querylist)
 #else
 		 ctl->server.service && !strcmp(ctl->server.service, KPOP_PORT ) &&
 #endif
-		 ctl->server.preauthenticate == A_KERBEROS_V4);
+		 ctl->server.authenticate == A_KERBEROS_V4);
 
 	    stringdump("pollname", ctl->server.pollname); 
 	    booldump("active", !ctl->server.skip); 
@@ -271,18 +276,24 @@ void dump_config(struct runctl *runp, struct query *querylist)
 	    numdump("envskip", ctl->server.envskip);
 	    stringdump("qvirtual", ctl->server.qvirtual);
  
-	    if (ctl->server.preauthenticate == A_ANY)
-		stringdump("preauth", "any");
-	    else if (ctl->server.preauthenticate == A_PASSWORD)
-		stringdump("preauth", "password");
-	    else if (ctl->server.preauthenticate == A_GSSAPI)
-		stringdump("preauth", "gssapi");
-	    else if (ctl->server.preauthenticate == A_KERBEROS_V4)
-		stringdump("preauth", "kerberos_v4");
-	    else if (ctl->server.preauthenticate == A_KERBEROS_V5)
-		stringdump("preauth", "kerberos_v5");
-	    else if (ctl->server.preauthenticate == A_SSH)
-		stringdump("preauth", "ssh");
+	    if (ctl->server.authenticate == A_ANY)
+		stringdump("auth", "any");
+	    else if (ctl->server.authenticate == A_PASSWORD)
+		stringdump("auth", "password");
+	    else if (ctl->server.authenticate == A_OTP)
+		stringdump("auth", "otp");
+	    else if (ctl->server.authenticate == A_NTLM)
+		stringdump("auth", "ntlm");
+	    else if (ctl->server.authenticate == A_CRAM_MD5)
+		stringdump("auth", "cram-md5");
+	    else if (ctl->server.authenticate == A_GSSAPI)
+		stringdump("auth", "gssapi");
+	    else if (ctl->server.authenticate == A_KERBEROS_V4)
+		stringdump("auth", "kerberos_v4");
+	    else if (ctl->server.authenticate == A_KERBEROS_V5)
+		stringdump("auth", "kerberos_v5");
+	    else if (ctl->server.authenticate == A_SSH)
+		stringdump("auth", "ssh");
 
 #if defined(HAVE_GETHOSTBYNAME) && defined(HAVE_RES_SEARCH)
 	    booldump("dns", ctl->server.dns);
