@@ -158,6 +158,7 @@ int main(int argc, char **argv)
 
     envquery(argc, argv);
 #ifdef ENABLE_NLS
+    setlocale (LC_ALL, "");
     bindtextdomain(PACKAGE, LOCALEDIR);
     textdomain(PACKAGE);
 #endif
@@ -323,7 +324,7 @@ int main(int argc, char **argv)
     {
 	if (ctl->active && !(implicitmode && ctl->server.skip)&&!ctl->password)
 	{
-	    if (ctl->server.preauthenticate > A_PASSWORD)
+	    if (NO_PASSWORD(ctl))
 		/* Server won't care what the password is, but there
 		   must be some non-null string here.  */
 		ctl->password = ctl->remotename;
@@ -493,8 +494,7 @@ int main(int argc, char **argv)
     for (ctl = querylist; ctl; ctl = ctl->next)
     {
 	if (ctl->active && !(implicitmode && ctl->server.skip)
-		&& ctl->server.preauthenticate <= A_PASSWORD
-		&& !ctl->password)
+		&& !NO_PASSWORD(ctl) && !ctl->password)
 	{
 	    if (!isatty(0))
 	    {
@@ -866,7 +866,7 @@ static void optmerge(struct query *h2, struct query *h1, int force)
     FLAG_MERGE(server.port);
 #endif /* INET6_ENABLE */
     FLAG_MERGE(server.interval);
-    FLAG_MERGE(server.preauthenticate);
+    FLAG_MERGE(server.authenticate);
     FLAG_MERGE(server.timeout);
     FLAG_MERGE(server.envelope);
     FLAG_MERGE(server.envskip);
@@ -1101,8 +1101,8 @@ static int load_params(int argc, char **argv, int optind)
 	     * If we're using Kerberos for authentication, we need 
 	     * the FQDN in order to generate capability keys.  */
 	    if (ctl->server.protocol==P_ETRN || ctl->server.protocol==P_ODMR
-		|| ctl->server.preauthenticate == A_KERBEROS_V4
-		|| ctl->server.preauthenticate == A_KERBEROS_V5)
+		|| ctl->server.authenticate == A_KERBEROS_V4
+		|| ctl->server.authenticate == A_KERBEROS_V5)
 		if (strcmp(fetchmailhost, "localhost") == 0)
 			fetchmailhost = host_fqdn();
 
@@ -1192,8 +1192,8 @@ static int load_params(int argc, char **argv, int optind)
 #ifdef HAVE_GETHOSTBYNAME
 	    else if (!configdump)
 	    {
-		if (ctl->server.preauthenticate==A_KERBEROS_V4 ||
-		      ctl->server.preauthenticate==A_KERBEROS_V5 ||
+		if (ctl->server.authenticate==A_KERBEROS_V4 ||
+		      ctl->server.authenticate==A_KERBEROS_V5 ||
 		    (ctl->server.dns && MULTIDROP(ctl)))
 		{
 		    struct hostent	*namerec;
@@ -1547,7 +1547,7 @@ static void dump_params (struct runctl *runp,
 	printf(_("Options for retrieving from %s@%s:\n"),
 	       ctl->remotename, visbuf(ctl->server.pollname));
 
-	if (ctl->server.via && (ctl->server.protocol < P_ETRN))
+	if (ctl->server.via && MAILBOX_PROTOCOL(ctl))
 	    printf(_("  Mail will be retrieved via %s\n"), ctl->server.via);
 
 	if (ctl->server.interval)
@@ -1558,7 +1558,7 @@ static void dump_params (struct runctl *runp,
 	if (ctl->server.skip || outlevel >= O_VERBOSE)
 	    printf(_("  This host %s be queried when no host is specified.\n"),
 		   ctl->server.skip ? _("will not") : _("will"));
-	if (ctl->server.preauthenticate <= A_PASSWORD)
+	if (!NO_PASSWORD(ctl))
 	{
 	    if (!ctl->password)
 		printf(_("  Password will be prompted for.\n"));
@@ -1582,10 +1582,10 @@ static void dump_params (struct runctl *runp,
 #else /* INET6_ENABLE */
 	    && ctl->server.port == KPOP_PORT
 #endif /* INET6_ENABLE */
-	    && (ctl->server.preauthenticate == A_KERBEROS_V4 ||
-		ctl->server.preauthenticate == A_KERBEROS_V5))
+	    && (ctl->server.authenticate == A_KERBEROS_V4 ||
+		ctl->server.authenticate == A_KERBEROS_V5))
 	    printf(_("  Protocol is KPOP with Kerberos %s authentication"),
-		   ctl->server.preauthenticate == A_KERBEROS_V5 ? "V" : "IV");
+		   ctl->server.authenticate == A_KERBEROS_V5 ? "V" : "IV");
 	else
 	    printf(_("  Protocol is %s"), showproto(ctl->server.protocol));
 #if INET6_ENABLE
@@ -1599,26 +1599,35 @@ static void dump_params (struct runctl *runp,
 #endif /* INET6_ENABLE */
 	else if (outlevel >= O_VERBOSE)
 	    printf(_(" (using default port)"));
-	if (ctl->server.uidl && (ctl->server.protocol < P_ETRN))
+	if (ctl->server.uidl && MAILBOX_PROTOCOL(ctl))
 	    printf(_(" (forcing UIDL use)"));
 	putchar('.');
 	putchar('\n');
-	switch (ctl->server.preauthenticate)
+	switch (ctl->server.authenticate)
 	{
 	case A_ANY:
-	    printf(_("  All authentication methods will be described.\n"));
+	    printf(_("  All available authentication methods will be tried.\n"));
 	    break;
 	case A_PASSWORD:
 	    printf(_("  Password authentication will be forced.\n"));
 	    break;
+	case A_NTLM:
+	    printf(_("  NTLM authentication will be forced.\n"));
+	    break;
+	case A_OTP:
+	    printf(_("  OTP authentication will be forced.\n"));
+	    break;
+	case A_CRAM_MD5:
+	    printf(_("  CRAM-Md5 authentication will be forced.\n"));
+	    break;
 	case A_GSSAPI:
-	    printf(_("  GSSAPI preauthentication will be forced.\n"));
+	    printf(_("  GSSAPI authentication will be forced.\n"));
 	    break;
 	case A_KERBEROS_V4:
-	    printf(_("  Kerberos V4 preauthentication will be forced.\n"));
+	    printf(_("  Kerberos V4 authentication will be forced.\n"));
 	    break;
 	case A_KERBEROS_V5:
-	    printf(_("  Kerberos V5 preauthentication will be forced.\n"));
+	    printf(_("  Kerberos V5 authentication will be forced.\n"));
 	    break;
 	case A_SSH:
 	    printf(_("  End-to-end encryption assumed.\n"));
@@ -1637,7 +1646,7 @@ static void dump_params (struct runctl *runp,
 	else
 	    printf(".\n");
 
-	if (ctl->server.protocol < P_ETRN) {
+	if (MAILBOX_PROTOCOL(ctl)) {
 		if (!ctl->mailboxes->id)
 		    printf(_("  Default mailbox selected.\n"));
 		else
@@ -1704,7 +1713,7 @@ static void dump_params (struct runctl *runp,
 		    printf(_("  SMTP message batch limit is %d.\n"), ctl->batchlimit);
 		else if (outlevel >= O_VERBOSE)
 		    printf(_("  No SMTP message batch limit (--batchlimit 0).\n"));
-		if (ctl->server.protocol < P_ETRN)
+		if (MAILBOX_PROTOCOL(ctl))
 		{
 		    if (NUM_NONZERO(ctl->expunge))
 			printf(_("  Deletion interval between expunges forced to %d (--expunge %d).\n"), ctl->expunge, ctl->expunge);
@@ -1714,7 +1723,7 @@ static void dump_params (struct runctl *runp,
 	}
 	if (ctl->bsmtp)
 	    printf(_("  Messages will be appended to %s as BSMTP\n"), visbuf(ctl->bsmtp));
-	else if (ctl->mda && (ctl->server.protocol < P_ETRN))
+	else if (ctl->mda && MAILBOX_PROTOCOL(ctl))
 	    printf(_("  Messages will be delivered with \"%s\".\n"), visbuf(ctl->mda));
 	else
 	{
@@ -1735,7 +1744,7 @@ static void dump_params (struct runctl *runp,
 		printf(_("  Address to be put in RCPT TO lines shipped to SMTP will be %s\n"),
 		       ctl->smtpname);
 	}
-	if (ctl->server.protocol < P_ETRN)
+	if (MAILBOX_PROTOCOL(ctl))
 	{
 		if (ctl->antispam != (struct idlist *)NULL)
 		{
@@ -1759,7 +1768,7 @@ static void dump_params (struct runctl *runp,
 		   visbuf(ctl->postconnect));
 	else if (outlevel >= O_VERBOSE)
 	    printf(_("  No post-connection command.\n"));
-	if (ctl->server.protocol < P_ETRN) {
+	if (MAILBOX_PROTOCOL(ctl)) {
 		if (!ctl->localnames)
 		    printf(_("  No localnames declared for this host.\n"));
 		else
@@ -1856,7 +1865,7 @@ static void dump_params (struct runctl *runp,
 	else if (outlevel >= O_VERBOSE)
 	    printf(_("  No plugout command specified.\n"));
 
-	if (ctl->server.protocol > P_POP2 && (ctl->server.protocol < P_ETRN))
+	if (ctl->server.protocol > P_POP2 && MAILBOX_PROTOCOL(ctl))
 	{
 	    if (!ctl->oldsaved)
 		printf(_("  No UIDs saved from this host.\n"));
