@@ -15,6 +15,15 @@
 #define		P_ETRN		7
 #define		P_ODMR		8
 
+/* 
+ * We need to distinguish between mailbox and mailbag protocols.
+ * Under a mailbox protocol wwe're pulling mail for a speecific user
+ * and the transaction must be authenticated.  Under a mailbag protocol
+ * we're fetching mail for an entire domain; the client and server
+ * authenticate to each other but no per-user authentication is needed.
+ */ 
+#define MAILBOX_PROTOCOL(ctl)	((ctl)->server.protocol < P_ETRN)
+
 #if INET6_ENABLE
 #define		SMTP_PORT	"smtp"
 #define		KPOP_PORT	"kpop"
@@ -28,13 +37,19 @@
 #define		SPOP3_PORT	995
 #endif
 
-/* preauthentication types */
+/* authentication types */
 #define		A_ANY		0	/* use the first method that works */
-#define		A_PASSWORD	1	/* password or inline authentication */
-#define		A_KERBEROS_V4	2	/* preauthenticate w/ Kerberos V4 */
-#define		A_KERBEROS_V5	3	/* preauthenticate w/ Kerberos V5 */
-#define 	A_GSSAPI	4	/* preauthenticate with GSSAPI */
-#define		A_SSH		5	/* preauthentication at session level */
+#define		A_PASSWORD	1	/* password authentication */
+#define		A_NTLM		2	/* Microsoft NTLM protocol */
+#define		A_CRAM_MD5	3	/* CRAM-MD5 shrouding (RFC2195) */
+#define		A_OTP		4	/* One-time password (RFC1508) */
+#define		A_KERBEROS_V4	5	/* authenticate w/ Kerberos V4 */
+#define		A_KERBEROS_V5	6	/* authenticate w/ Kerberos V5 */
+#define 	A_GSSAPI	7	/* authenticate with GSSAPI */
+#define		A_SSH		8	/* authentication at session level */
+
+/* some protocols (KERBEROS, GSSAPI, SSH) don't require a password */
+#define NO_PASSWORD(ctl)	((ctl)->server.authenticate > A_OTP || !MAILBOX_PROTOCOL(ctl))
 
 /*
  * Definitions for buffer sizes.  We get little help on setting maxima
@@ -195,7 +210,7 @@ struct hostdata		/* shared among all user connections to given server */
     int port;				/* TCP/IP service port number */
 #endif /* INET6_ENABLE */
     int interval;			/* # cycles to skip between polls */
-    int preauthenticate;		/* preauthentication mode to try */
+    int authenticate;			/* authentication mode to try */
     int timeout;			/* inactivity timout in seconds */
     char *envelope;			/* envelope address list header */
     int envskip;			/* skip to numbered envelope header */
@@ -361,7 +376,7 @@ extern int pass;		/* number of re-polling pass */
 extern flag configdump;		/* dump control blocks as Python dictionary */
 extern const char *fetchmailhost;
 				/* either "localhost" or an FQDN */
-extern suppress_tags;		/* suppress tags in tagged protocols? */
+extern int suppress_tags;	/* suppress tags in tagged protocols? */
 #ifdef SDPS_ENABLE
 extern char *sdps_envfrom;
 extern char *sdps_envto;
