@@ -78,6 +78,18 @@ int imap_ok(int sock, char *argbuf)
 	}
 	else if (strstr(buf, "PREAUTH"))
 	    preauth = TRUE;
+	/*
+	 * The server may decide to make the mailbox read-only, 
+	 * which causes fetchmail to go into a endless loop
+	 * fetching the same message over and over again. 
+	 * 
+	 * This checks for the condition and aborts if 
+	 * the mailbox is read-only. 
+	 *
+	 * See RFC 2060 section 6.3.1 (SELECT).
+	 */ 
+	else if (strstr(buf, "[READ-ONLY]"))
+	    return(PS_LOCKBUSY);
     } while
 	(tag[0] != '\0' && strncmp(buf, tag, strlen(tag)));
 
@@ -182,7 +194,6 @@ static int do_imap_ntlm(int sock, struct query *ctl)
 	report(stdout, "IMAP> %s\n", msgbuf);
       
     strcat(msgbuf,"\r\n");
-
     SockWrite (sock, msgbuf, strlen (msgbuf));
   
     if ((result = gen_recv (sock, msgbuf, sizeof msgbuf)))
@@ -270,7 +281,7 @@ int imap_getauth(int sock, struct query *ctl, char *greeting)
      * If either (a) we saw a PREAUTH token in the greeting, or
      * (b) the user specified ssh preauthentication, then we're done.
      */
-    if (preauth || ctl->server.preauthenticate == A_SSH)
+    if (preauth || ctl->server.authenticate == A_SSH)
     {
         preauth = FALSE;  /* reset for the next session */
         return(PS_SUCCESS);
@@ -281,16 +292,16 @@ int imap_getauth(int sock, struct query *ctl, char *greeting)
      * Try the protocol variants that don't require passwords first.
      */
 #ifdef GSSAPI
-    if ((ctl->server.preauthenticate == A_ANY 
-	 || ctl->server.preauthenticate==A_GSSAPI)
+    if ((ctl->server.authenticate == A_ANY 
+	 || ctl->server.authenticate==A_GSSAPI)
 	&& strstr(capabilities, "AUTH=GSSAPI"))
 	return(do_gssauth(sock, ctl->server.truename, ctl->remotename));
 #endif /* GSSAPI */
 
 #ifdef KERBEROS_V4
-    if ((ctl->server.preauthenticate == A_ANY 
-	 || ctl->server.preauthenticate==A_KERBEROS_V4
-	 || ctl->server.preauthenticate==A_KERBEROS_V5) 
+    if ((ctl->server.authenticate == A_ANY 
+	 || ctl->server.authenticate==A_KERBEROS_V4
+	 || ctl->server.authenticate==A_KERBEROS_V5) 
 	&& strstr(capabilities, "AUTH=KERBEROS_V4"))
     {
 	if ((ok = do_rfc1731(sock, "AUTHENTICATE", ctl->server.truename)))
@@ -305,7 +316,9 @@ int imap_getauth(int sock, struct query *ctl, char *greeting)
      * in a challenge-response.
      */
 
-    if (strstr(capabilities, "AUTH=CRAM-MD5"))
+    if ((ctl->server.authenticate == A_ANY 
+	 || ctl->server.authenticate==A_CRAM_MD5)
+	&& strstr(capabilities, "AUTH=CRAM-MD5"))
     {
 	if ((ok = do_cram_md5 (sock, "AUTHENTICATE", ctl)))
 	    /* SASL cancellation of authentication */
@@ -314,13 +327,31 @@ int imap_getauth(int sock, struct query *ctl, char *greeting)
     }
 
 #if OPIE_ENABLE
-    if (strstr(capabilities, "AUTH=X-OTP"))
-	return(do_otp(sock, ctl);
+    if ((ctl->server.authenticate == A_ANY 
+	 || ctl->server.authenticate==A_OTP)
+	&& strstr(capabilities, "AUTH=X-OTP"))
+	return(do_otp(sock, ctl));
+#else
+    if (ctl->server.authenticate==A_NTLM)
+    {
+	report(stderr, 
+	   _("Required OTP capability not compiled into fetchmail\n"));
+	return(PS_AUTHFAIL);
+    }
 #endif /* OPIE_ENABLE */
 
 #ifdef NTLM_ENABLE
-    if (strstr (capabilities, "AUTH=NTLM"))
-        return(do_imap_ntlm (sock, ctl));
+    if ((ctl->server.authenticate == A_ANY 
+	 || ctl->server.authenticate==A_NTLM) 
+	&& strstr (capabilities, "AUTH=NTLM"))
+	return(do_imap_ntlm(sock, ctl));
+#else
+    if (ctl->server.authenticate==A_NTLM)
+    {
+	report(stderr, 
+	   _("Required NTLM capability not compiled into fetchmail\n"));
+	return(PS_AUTHFAIL);
+    }
 #endif /* NTLM_ENABLE */
 
 #ifdef __UNUSED__	/* The Cyrus IMAP4rev1 server chokes on this */
