@@ -101,7 +101,12 @@ int pop3_ok (int sock, char *argbuf)
 		ok = PS_LOCKBUSY;
 	    else
 		ok = PS_AUTHFAIL;
-	    if (*bufp)
+	    /*
+	     * We always want to pass the user lock-busy messages, because
+	     * they're red flags.  Other stuff (like AUTH failures on non-
+	     * RFC1734 servers) only if we're debugging.
+	     */
+	    if (*bufp && (ok == PS_LOCKBUSY || outlevel >= O_MONITOR))
 	      report(stderr, "%s\n", bufp);
 	}
 	else
@@ -134,15 +139,6 @@ int pop3_getauth(int sock, struct query *ctl, char *greeting)
         ctl->server.sdps = TRUE;
 #endif /* SDPS_ENABLE */
 
-    /* 
-     * In theory, we ought to probe with CAPA here (RFC 2449).
-     * But AFAIK this commpand is not widely implemented, and
-     * we have our own tests for optional commands, and it seems
-     * vanishingly unlikely that the RFC 2449 extended responses
-     * [IN-USE] and [LOGIN-DELAY] will ever be accidentally spoofed.
-     * So we'll not bother, and save ourselves the overhead.
-     */
-
     switch (ctl->server.protocol) {
     case P_POP3:
 #ifdef RPA_ENABLE
@@ -169,48 +165,28 @@ int pop3_getauth(int sock, struct query *ctl, char *greeting)
 
 	    return(PS_AUTHFAIL);
 	}
-	else /* not a CompuServe account */
 #endif /* RPA_ENABLE */
-	    ok = gen_transact(sock, "USER %s", ctl->remotename);
-
-#if OPIE_ENABLE
-	/* see RFC1938: A One-Time Password System */
-	if (challenge = strstr(lastok, "otp-")) {
-	  char response[OPIE_RESPONSE_MAX+1];
-	  int i;
-
-	  i = opiegenerator(challenge, !strcmp(ctl->password, "opie") ? "" : ctl->password, response);
-	  if ((i == -2) && !run.poll_interval) {
-	    char secret[OPIE_SECRET_MAX+1];
-	    fprintf(stderr, _("Secret pass phrase: "));
-	    if (opiereadpass(secret, sizeof(secret), 0))
-	      i = opiegenerator(challenge,  secret, response);
-	    memset(secret, 0, sizeof(secret));
-	  };
-
-	  if (i) {
-	    ok = PS_ERROR;
-	    break;
-	  };
-
-	  ok = gen_transact(sock, "PASS %s", response);
-	  break;
-	}
-#endif /* OPIE_ENABLE */
 
 	/*
-	 * AUTH command may return a list of available mechanisms.
-	 * if it doesn't, no harm done.  Efficiency hack: most servers
-	 * don't implement this, so don't do it at all unless the
-	 * server advertises APOP with <> in the greeting line.  This
-	 * certainly catches IMAP-2000's POP3 gateway.
+	 * CAPA command may return a list including available
+	 * authentication mechanisms.  if it doesn't, no harm done, we
+	 * just fall back to a plain login.  Note that this code 
+	 * latches the server's authentication type, so that in daemon mode
+	 * the CAPA check only needs to be done once at start of run.
+	 *
+	 * APOP was introduced in RFC 1450, and CAPA not until
+	 * RFC2449. So the < check is an easy way to prevent CAPA from
+	 * being sent to the more primitive POP3 servers dating from
+	 * RFC 1081 and RFC 1225, which seem more likely to choke on
+	 * it.  This certainly catches IMAP-2000's POP3 gateway.
 	 * 
 	 * These authentication methods are blessed by RFC1734,
-	 * POP3 AUTHentication command.
+	 * describing the POP3 AUTHentication command.
 	 */
-	if (strchr(greeting, '<') && gen_transact(sock, "AUTH") == 0)
+	if (ctl->server.authenticate == A_ANY 
+	    && strchr(greeting, '<') 
+	    && gen_transact(sock, "CAPA") == 0)
 	{
-	    char buffer[10];
 #if defined(GSSAPI)
 	    flag has_gssapi = FALSE;
 #endif /* defined(GSSAPI) */
@@ -221,6 +197,7 @@ int pop3_getauth(int sock, struct query *ctl, char *greeting)
 #ifdef OPIE_ENABLE
 	    flag has_opie = FALSE;
 #endif /* OPIE_ENABLE */
+	    char buffer[64];
 
 	    /* determine what authentication methods we have available */
 	    while ((ok = gen_recv(sock, buffer, sizeof(buffer))) == 0)
@@ -228,39 +205,63 @@ int pop3_getauth(int sock, struct query *ctl, char *greeting)
 		if (DOTLINE(buffer))
 		    break;
 #if defined(GSSAPI)
-		if (strncasecmp(buffer, "GSSAPI", 8) == 0)
+		if (strstr(buffer, "GSSAPI"))
 		    has_gssapi = TRUE;
 #endif /* defined(GSSAPI) */
 #if defined(KERBEROS_V4) || defined(KERBEROS_V5)
-		if (strncasecmp(buffer, "KERBEROS_V4", 8) == 0)
+		if (strstr(buffer, "KERBEROS_V4"))
 		    has_kerberos = TRUE;
 #endif /* defined(KERBEROS_V4) || defined(KERBEROS_V5) */
-		if (strncasecmp(buffer, "CRAM-MD5", 8) == 0)
-		    has_cram = TRUE;
 #ifdef OPIE_ENABLE
-		if (strncasecmp(buffer, "X-OTP", 8) == 0)
-		    has_opie = TRUE;
+		if (strstr(buffer, "X-OTP"))
+		    has_otp = TRUE;
 #endif /* OPIE_ENABLE */
+		if (strstr(buffer, "CRAM-MD5"))
+		    has_cram = TRUE;
 	    }
 
+	    /*
+	     * Here's where we set priorities.  Note that we must do tests
+	     * in *reverse* order of desirability.
+	     */
+	    if (has_cram)
+		ctl->server.authenticate = A_CRAM_MD5;
+#ifdef OPIE_ENABLE
+	    if (has_opie)
+		ctl->server.authenticate = A_OTP;
+#endif /* OPIE_ENABLE */
 #if defined(GSSAPI)
-	    if (has_kerberos)
-		return(do_gssauth(sock, "AUTH", 
-				  ctl->server.truename, ctl->remotename));
+	    if (has_gssapi)
+		ctl->server.authenticate = A_GSSAPI;
 #endif /* defined(GSSAPI) */
 #if defined(KERBEROS_V4) || defined(KERBEROS_V5)
 	    if (has_kerberos)
-		return(do_rfc1731(sock, "AUTH", ctl->server.truename));
+		ctl->server.authenticate = A_KERBEROS_V4;
 #endif /* defined(KERBEROS_V4) || defined(KERBEROS_V5) */
-	    if (has_cram)
-		return(do_cram_md5(sock, "AUTH", ctl));
+	}
+
+	/*
+	 * OK, we have an authentication type now.
+	 */
+#if defined(KERBEROS_V4) || defined(KERBEROS_V5)
+	if (ctl->server.authenticate == A_KERBEROS_V4
+	    	|| ctl->server.authenticate == A_KERBEROS_V5)
+	    return(do_rfc1731(sock, "AUTH", ctl->server.truename));
+#endif /* defined(KERBEROS_V4) || defined(KERBEROS_V5) */
+#if defined(GSSAPI)
+	if (ctl->server.authenticate==A_GSSAPI))
+	    return(do_gssauth(sock, "AUTH", 
+			      ctl->server.truename, ctl->remotename));
+#endif /* defined(GSSAPI) */
 #ifdef OPIE_ENABLE
-	    if (has_opie)
-		do_otp(sock, "AUTH", ctl)
+	if (ctl->server.authenticate == A_OTP)
+	    do_otp(sock, "AUTH", ctl)
 #endif /* OPIE_ENABLE */
-       }
+	if (ctl->server.authenticate == A_CRAM_MD5)
+	    return(do_cram_md5(sock, "AUTH", ctl));
 
 	/* ordinary validation, no one-time password or RPA */ 
+	gen_transact(sock, "USER %s", ctl->remotename);
 	ok = gen_transact(sock, "PASS %s", ctl->password);
 	break;
 
